@@ -1,16 +1,18 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib v0.11.100
+# hspylib v0.11.101
 #
 # Package: main.hspylib.core
 """Package initialization."""
 
 __all__ = [
   'config', 
+  'constants', 
   'crud', 
   'enums', 
   'exception', 
   'metaclass', 
+  'preconditions', 
   'tools'
 ]
-__version__ = '0.11.100'
+__version__ = '0.11.101'
