@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib v0.11.100
+# hspylib v0.11.101
 #
 # Package: main.hspylib.core.tools
 """Package initialization."""
@@ -8,11 +8,9 @@
 __all__ = [
   'collection_filter', 
   'commons', 
-  'constants', 
   'git_tools', 
-  'preconditions', 
   'text_tools', 
   'validator', 
   'zoned_datetime'
 ]
-__version__ = '0.11.100'
+__version__ = '0.11.101'
