@@ -13,15 +13,16 @@
    Copyright 2022, HSPyLib team
 """
 
-from typing import Any, List, Optional, Tuple, Union, Dict
+from typing import Any, Dict, List, Optional, Tuple, Union
+
 import requests
 from requests import exceptions as ex
+
 from hspylib.core.enums.http_method import HttpMethod
 from hspylib.core.tools.commons import sysout
 from hspylib.modules.fetch.http_response import HttpResponse
 
 
-
 def fetch(
     url: str,
     method: HttpMethod = HttpMethod.GET,
