@@ -14,14 +14,15 @@
 """
 
 import collections
-from typing import List, Type, TypeVar, Union, Tuple
+from typing import List, Tuple, Type, TypeVar, Union
+
 from PyQt5.QtCore import QAbstractTableModel, QModelIndex, Qt, QVariant
 from PyQt5.QtGui import QPalette
 from PyQt5.QtWidgets import QTableView
+
 from hspylib.core.tools.collection_filter import CollectionFilter, FilterConditions
 from hspylib.core.tools.commons import class_attribute_names, class_attribute_values
 
-
 T = TypeVar('T')
 
 
